@@ -336,6 +336,19 @@ class LoadMaster(HttpClient):
         response = self._get('/killaslinstance')
         return send_response(response)
 
+    def show_interface(self, interface_id=1):
+        if not isinstance(interface_id, int):
+            raise ValidationError('"interface_id" must be an integer')
+        response = self._get('/showiface', {"interface": interface_id})
+        data = get_data(response)
+        interface = data["Interface"]
+        address_cidr_split = interface["IPAddress"].split("/")
+        if len(address_cidr_split) > 1:
+            # Address/cidr is set in this case and can safely be split
+            interface["IPAddress"] = address_cidr_split[0]
+            interface["cidr"] = address_cidr_split[1]
+        return interface
+
 
 class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
